@@ -98,6 +98,16 @@ class ContainerTechnology:
             for filename in shpc.utils.recursive_find(registry):
                 yield registry, filename
 
+    def iter_modules(self):
+        """
+        Iterate over modules found across the registry
+        """
+        for registry in self.settings.registry:
+            for filename in shpc.utils.recursive_find(registry):
+                yield registry, os.path.dirname(filename).replace(registry, "").strip(
+                    os.sep
+                )
+
     def guess_tag(self, module_name, allow_fail=False):
         """
         If a user asks for a name without a tag, try to figure it out.
