@@ -3,8 +3,10 @@ __copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 
-from shpc.logger import logger
+from shpc.logger import logger, underline, add_prefix
 import shpc.main.schemas as schemas
+import shpc.utils as utils
+import shpc.main.container.update as update
 import shlex
 
 try:
@@ -20,7 +22,9 @@ here = os.path.abspath(os.path.dirname(__file__))
 
 
 class Tags:
-    """Make it easy to interact with tags (name and version)"""
+    """
+    Make it easy to interact with tags (name and version)
+    """
 
     def __init__(self, tagdict, latest):
         tagdict.update(latest)
@@ -125,6 +129,27 @@ class ContainerConfig:
         name = self.docker or self.oras or self.gh
         return ContainerName(name)
 
+    def update(self, dryrun=False, filters=None):
+        """
+        Update a container.yaml, meaning the tags and latest.
+        """
+        updated = None
+        if self.docker or self.oras:
+            previous_tags = self.get("tags", {})
+            previous_latest = self.get("latest", {})
+            updated = update.update_config_tags(self, filters=filters)
+
+            # print the container name and latest tag:
+            print(add_prefix(underline(self.docker or self.oras)))
+            print(add_prefix("Latest"))
+            update.print_diff(previous_latest, updated.get("latest"), True)
+            print(add_prefix("Tags"))
+            update.print_diff(previous_tags, updated.get("tags"))
+
+            # Take a "diff" of tags
+            if not dryrun:
+                updated.save(updated.package_file)
+
     @property
     def latest(self):
         """
@@ -155,6 +180,9 @@ class ContainerConfig:
             self.tag = self.tags.get(tag)
 
     def dump(self, out=None):
+        """
+        Dump (display) the config to an output.
+        """
         out = out or sys.stdout
         yaml = YAML()
         yaml.dump(self._config, out)
@@ -265,9 +293,7 @@ class ContainerConfig:
         """
         Save the container.yaml to file. This is usually for shpc add.
         """
-        yaml = YAML()
-        with open(package_file, "w") as fd:
-            yaml.dump(self._config, fd)
+        utils.write_yaml(self._config, package_file)
 
     def load(self, package_file):
         """
@@ -278,9 +304,5 @@ class ContainerConfig:
             logger.exit("%s does not exist." % package_file)
 
         # Default to round trip so we can save comments
-        yaml = YAML()
-
-        # Store the original settings for update as we go
-        with open(package_file, "r") as fd:
-            self._config = yaml.load(fd.read())
         self.package_file = package_file
+        self._config = utils.read_yaml(package_file)
