@@ -6,8 +6,6 @@
 # Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
 # with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-import pytest
-import shutil
 import os
 
 import shpc.main.container as container
